django-carbon
=============

Django carbon is a set of abstract models and apps to help make building the foundational web components easier.

Current Features:
- Pages with core SEO helpers
- Basic user accounts
- Media library
- Server-side CSS and JS package compilation, concatenation, minification and versioning
- Dynamic form generation library
- Email templating with tracking and basic subscription settings
- Basic blog

Example Implementation Here: https://github.com/ninapavlich/caledon


Future models:

Account:
- login from third party service
- bio and social network fields

Sharing:
- Social network sharing model

Tracking:
- Simple tracking model for views and shares

Comments:
- Comment with moderation, upvote/downvote, sorting
